==> open-xchange-core_7.6.2.orig.tar.bz2: open-xchange-core-7.6.2/com.openexchange.server/src/com/openexchange/groupware/infostore/InfostoreFacades.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.infostore;

import com.openexchange.groupware.infostore.osgi.InfostoreActivator;


/**
 * {@link InfostoreFacades} - Utility class for InfoStore.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class InfostoreFacades {

    /**
     * Initializes a new {@link InfostoreFacades}.
     */
    private InfostoreFacades() {
        super();
    }

    /**
     * Checks if needed InfoStore bundle(s) is/are available.
     *
     * @return <code>true</code> if available; otherwise <code>false</code>
     */
    public static boolean isInfoStoreAvailable() {
        final InfostoreAvailable available = InfostoreActivator.INFOSTORE_FILE_STORAGE_AVAILABLE.get();
        return (null == available || available.available());
    }

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.server/src/com/openexchange/groupware/infostore/InfostoreFacades.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.infostore;

import com.openexchange.groupware.infostore.osgi.InfostoreActivator;


/**
 * {@link InfostoreFacades} - Utility class for InfoStore.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class InfostoreFacades {

    /**
     * Initializes a new {@link InfostoreFacades}.
     */
    private InfostoreFacades() {
        super();
    }

    /**
     * Checks if needed InfoStore bundle(s) is/are available.
     *
     * @return <code>true</code> if available; otherwise <code>false</code>
     */
    public static boolean isInfoStoreAvailable() {
        final InfostoreAvailable available = InfostoreActivator.INFOSTORE_FILE_STORAGE_AVAILABLE.get();
        return (null == available || available.available());
    }

    /**
     * Performs a safe rollback for each {@link InfostoreFacade} instance
     *
     * @param infostoreFacades The instances to be rolled-back
     */
    public static void rollback(InfostoreFacade... infostoreFacades) {
        if (null != infostoreFacades) {
            for (InfostoreFacade infostoreFacade : infostoreFacades) {
                if (null != infostoreFacade) {
                    try {
                        infostoreFacade.rollback();
                    } catch (Exception e) {
                        // Ignore
                    }
                }
            }
        }
    }

    /**
     * Performs a safe finish for each {@link InfostoreFacade} instance
     *
     * @param infostoreFacades The instances to be finished
     */
    public static void finish(InfostoreFacade... infostoreFacades) {
        if (null != infostoreFacades) {
            for (InfostoreFacade infostoreFacade : infostoreFacades) {
                if (null != infostoreFacade) {
                    try {
                        infostoreFacade.finish();
                    } catch (Exception e) {
                        // Ignore
                    }
                }
            }
        }
    }

}
